@@ -1,15 +1,9 @@
-import pytest
 import moto
 import boto3
 
 
-@pytest.fixture
-def mock_s3():
-    with moto.mock_s3():
-        yield
-
-
-def test_s3_bucket_contains_object_assertion(mock_s3):
+@moto.mock_s3
+def test_s3_bucket_contains_object_assertion():
     bucket = boto3.resource("s3").Bucket("mock")
     bucket.create(CreateBucketConfiguration={"LocationConstraint": "eu-west-1"})
     bucket.put_object(Key="foo", Body=b"123")
@@ -19,7 +13,8 @@ def test_s3_bucket_contains_object_assertion(mock_s3):
     assert bucket.does_not.contain("bar")
 
 
-def test_s3_bucket_empty_assertion(mock_s3):
+@moto.mock_s3
+def test_s3_bucket_empty_assertion():
     bucket = boto3.resource("s3").Bucket("mock")
     bucket.create(CreateBucketConfiguration={"LocationConstraint": "eu-west-1"})
     assert bucket.should_be.empty()
@@ -27,7 +22,8 @@ def test_s3_bucket_empty_assertion(mock_s3):
     assert bucket.should_not_be.empty()
 
 
-def test_s3_bucket_exists_assertion(mock_s3):
+@moto.mock_s3
+def test_s3_bucket_exists_assertion():
     bucket = boto3.resource("s3").Bucket("mock")
     assert bucket.should_not.exist()
     assert bucket.does_not.exist()
